@@ -4,7 +4,7 @@ set -ex
 
 # TODO This is the "test phase", tweak it as you see fit
 main() {
-    cargo fmt --all -- --write-mode=diff
+    cargo fmt --all
 
     cross build --target $TARGET
     cross build --target $TARGET --release
