@@ -11,22 +11,25 @@ extern crate libc;
 
 use self::libc::{uname, utsname};
 use super::Uname;
-use std::mem;
-use std::ffi::CStr;
 use std::borrow::Cow;
+use std::ffi::CStr;
 use std::io;
+use std::mem;
 
 macro_rules! cstr2cow {
-    ($v:expr) => (
+    ($v:expr) => {
         unsafe { CStr::from_ptr($v.as_ref().as_ptr()).to_string_lossy() }
-    )
+    };
 }
 
+/// `PlatformInfo` handles retrieiving information for the current platform (a Unix-like operating
+/// in this case).
 pub struct PlatformInfo {
     inner: utsname,
 }
 
 impl PlatformInfo {
+    /// Creates a new instance of `PlatformInfo`.  This function *should* never fail.
     pub fn new() -> io::Result<Self> {
         unsafe {
             let mut uts: utsname = mem::uninitialized();
